
*************************************************************************
* Replication .do file for Gerber, Huber, Doherty, Dowling, and Ha 2010 *
* Source data is CCAP 2007/8 survey with missing value flags not set,   *
*  data release 2.1 *****************************************************
*************************************************************************

clear 
set mem 700m
set more off

*local path="C:\Documents and Settings\dd384\My Documents\CCES.CCAP\CCAP\"
use "`path'ccap0001_common_output_r2_1_missingnotset.dta" if psweight~=. & psweight~=0

****************************
***DEMOGRAPHIC VARIABLES****
****************************

* State, drop if missing state
drop if profile66==0 | profile66==.
quietly tab profile66, gen(stateC_)
* drop State5 indicator--California (dominant category when weighted)
drop stateC_5

* Gender, drop if missing
recode profile54 (1=0) (2=1) (*=.), gen(female)
drop if female==.
label var female "Female = 1"

* Race, no missing
recode profile55 (1=1) (2/8=0) (*=.), gen(r_white)
drop if r_white==.
recode profile55 (1=0) (2=1) (3/8=0) (*=.), gen(r_black)
recode profile55 (1/2=0) (3=1) (4/8=0) (*=.), gen(r_hispanic)
recode profile55 (1/3=0) (4/8=1) (*=.), gen(r_other)
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Education, drop missing
recode profile57 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
drop if educ==.
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 3
drop educC_3
label var educC_1 "Educ<HS"
label var educC_2 "Educ=HS"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to 15, plus indicator for missing
* Not asked is dropped/missing
recode profile59 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (98=15), gen(income)

drop if income==.
gen incomemis = (income==15)
label var incomemis "Income Refused"
label var income "Income (1=<10k; 14=>150k; 15=RF)"

* Age
* No missing values
gen birthyr=profile51
label var birthyr "birth year"
gen age=2008-birthyr 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

****************************
**BIG FIVE ITEMS/TIPI     **
****************************

*All are 7 point scales, missing/skipped set to missing
#delimit ;

recode
profile40 profile41 profile42 profile43 profile44 profile45 profile46 profile47 profile48 profile49 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (*=.), 
gen(b_p_extraverted b_p_critical b_p_dependable b_p_anxious b_p_open b_p_reserved 
    b_p_sympathetic b_p_disorganized b_p_calm b_p_conventional);

*generate reversed values of items that need to be reverse scored;

recode
b_p_disorganized b_p_conventional b_p_critical b_p_anxious b_p_reserved
(7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7) (*=.),
gen(b_p_disorganized_R b_p_conventional_R b_p_critical_R b_p_anxious_R b_p_reserved_R);

#delimit cr

*Items range from 0 to 1 -- higher values indicate more of the trait

*Big Five - conscientiousness
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - openness to experiences
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"

*Big Five - agreeableness
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - emotional stability
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - extraversion
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*** OTHER PERSONALITY
recode mcap70 mcap72 (1=1) (2=.75) (3=.5) (4=.25) (5=0) (*=.)
recode mcap71 mcap73 (1=0) (2=.25) (3=.5) (4=.75) (5=1) (*=.)
alpha mcap70 mcap71 mcap72 mcap73
egen racialresent=rmean(mcap70 mcap71 mcap72 mcap73)
egen racialresentSTD=std(racialresent)
label var racialresent "Racial Resentment (0-1)"
label var racialresentSTD "Racial Resentment (M=0; SD=1)"

recode scap719 scap721 scap722 (1=0) (5=1) (*=.)
recode scap723 scap725 (1=1) (5=0) (*=.)
alpha scap719 scap721 scap722 scap723 scap725 , i
egen authoritarianism=rmean(scap719 scap721 scap722 scap723 scap725)
egen authoritarianismSTD=std(authoritarianism)
label var authoritarianism "Authoritarianism (0-1)"
label var authoritarianismSTD "Authoritarianism (M=0; SD=1)"

****************************
*****OUTCOME VARIABLES******
****************************

* Ideology
* Skipped/Not asked/Missing=Missing. Not sure=Moderate
recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (6=0) (*=.), gen(b_ideol_withns)
label var b_ideol_withns "Self-Reported Ideology (-2=Very Cons.;2=Very Lib., NotSure=0)"

* This is an alternative measure in which not sure is set to missing
* recode bcap700s (1=2) (2=1) (3=0) (4=-1) (5=-2) (*=.), gen(b_ideol)
* label var b_ideol "Self-Reported Ideology (-2=Very Cons.;2=Very Lib., NotSure+=Miss.)"

* Economic policy opinions
recode bcap20 (1=1) (2=2) (3=3) (*=.), gen(healthcare)
replace healthcare=(healthcare-1)/2
label var healthcare "Individualist Health Care (0-1)"

recode bcap24 (1=1) (2=2) (3=3) (4=4) (*=.), gen(taxes)
replace taxes=(taxes-1)/3
label var taxes "Oppose Taxing the Rich (0-1)"

egen ecoSTDhlth=std(healthcare)
egen ecoSTDtax=std(taxes)
gen ecoNSTD=(ecoSTDhlth+ecoSTDtax)/2
egen ecoSTD=std(ecoNSTD)

alpha ecoSTDhlth ecoSTDtax

* Social policy opinions
recode profile15 (1=1) (2=2) (3=3) (4=4) (*=.), gen(abortion)
replace abortion=(abortion-1)/3
label var abortion "Against Abortion (0-1)"

recode profile19 (1=1) (2=2) (3=3) (4=4) (*=.), gen(civilunion)
replace civilunion=(civilunion-1)/3
label var civilunion "Oppose Civil Unions (0-1)"

egen socSTDabort=std(abortion)
egen socSTDcivil=std(civilunion)
gen socNSTD=(socSTDabort+socSTDcivil)/2
egen socSTD=std(socNSTD)

alpha socSTDabort socSTDcivil

*Reverse economic and social policy opinion scales so that positive values are more liberal
replace socSTD=socSTD*-1
replace ecoSTD=ecoSTD*-1
label var socSTD "Social Domain (M0 SD1, -conservative to +liberal)"
label var ecoSTD "Economic Domain (M0 SD1, -conservative to +liberal)"

*** Interactions
quietly foreach i in female r_black r_hispanic r_other educC_1 educC_2 educC_4 educC_5 educC_6 income incomemis age age2 {
 gen BFcoX`i'=BF_conscientiousness*`i'
 label var BFcoX`i' "Conscientiousness x `i'"
 gen BFopX`i'=BF_openness*`i'
 label var BFopX`i' "Openness x `i'"
 gen BFagX`i'=BF_agreeableness*`i'
 label var BFagX`i' "Agreeableness x `i'"
 gen BFstX`i'=BF_stability*`i'
 label var BFstX`i' "Stability x `i'"
 gen BFexX`i'=BF_extraversion*`i'
 label var BFexX`i' "Extraversion x `i'"
}

**************************
*** Sample restrictions: First we'll set a constant sample and restrict to weighted cases
**************************

*All 20,000 cases have demographics

*Of these cases, 14,601 participated in the baseline survey and responded to all Big Five items. 
count if BF_extra~=. & BF_agre~=. & BF_consci~=. & BF_open~=. & BF_stab~=. & bdisp!=3
keep if BF_extra~=. & BF_agre~=. & BF_consci~=. & BF_open~=. & BF_stab~=. & bdisp!=3
count

*What is lost by including policy opinions and ideology? This brings us to 12,472 cases
quietly regress b_ideol_withns ecoSTD socSTD BF_* female r_black r_hispanic r_other age age2 educC_* stateC_* [pweight=psweight], cluster(profile66)
count if e(sample)
keep if e(sample)
count

*So the loss rate due to non-response is less than 15%:
disp 1-(12472/14601)

**************************
*** Appendix Table 1, Correlation among personality items
**************************
pwcorr BF_* [aweight=psweight]

**************************
*** Table 2, Summary Stats
**************************

summ b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis [aweight=psweight]
outsum b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis [aweight=psweight] using "logs/table2summarystats.out", bracket ctitle(Entire Sample) replace 

*set 2sd change in BF and Income in local vars
foreach i in co op ag st ex {
 quietly summ BF_`i' [aweight=psweight]
 local sd2_BF_`i'=2*r(sd)
}
quietly summ income if incomemis!=1
 local sd2_income=2*r(sd)

*by subgroup
outsum b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis if r_white==1 [aweight=psweight] using "logs/table2summarystats", bracket ctitle(Whites) append
outsum b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis if r_black==1 [aweight=psweight] using "logs/table2summarystats", bracket ctitle(Blacks) append
outsum b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis if r_hispanic==1 [aweight=psweight] using "logs/table2summarystats", bracket ctitle(Hispanics) append
outsum b_ideol_withns ecoSTD socSTD BF_* female r_white r_black r_hispanic r_other age age2 educ income incomemis if r_other==1 [aweight=psweight] using "logs/table2summarystats", bracket ctitle(Other Races) append

*quick comparison of personality and opinions for blacks and whites
foreach i in BF_con BF_op BF_ag BF_st BF_ex b_ideol_withns ecoSTD socSTD {
 table r_white if r_white==1 | r_black==1 [aweight=psweight], c(mean `i')
 quietly regress `i' r_white if r_white==1 | r_black==1 [aweight=psweight], robust
 test r_white
}

**************************
*** Table 3 Tobit, Aggregate Personality Effects
**************************

* Loop over DV's
foreach i in b_ideol_withns ecoSTD socSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01
 
 *two specifications (with and without income and eduation)
 tobit `i' BF_* female r_black r_hispanic r_other age age2 stateC_* [pweight=psweight], cluster(profile66) ll(`mini') ul(`maxi')
 
 *if first dv, then replace outreg, else append to outreg
 if "`i'"=="b_ideol_withns" {
  outreg BF_* female r_black r_hispanic r_other age age2 using "logs/table3aggregate.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) replace 
 }
 else {
  outreg BF_* female r_black r_hispanic r_other age age2 using "logs/table3aggregate.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) append
 }

 tobit `i' BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66) ll(`mini') ul(`maxi')
 outreg BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/table3aggregate.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) append

}

* This is the marginal effects for above specification #2

*Build marginal effect matrix and spit back out
quietly foreach i in b_ideol_withns ecoSTD socSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01

 quietly tobit `i' BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66)  ll(`mini') ul(`maxi')

 foreach j in co op ag st ex {
  
  lincom BF_`j'*`sd2_BF_`j''
  
  if "`j'"=="co" {
   matrix `i'_all = (r(estimate))
   matrix `i'_allci = (r(se))*1.959960458
  }
  else {
   matrix `i'_all = `i'_all\(r(estimate))
   matrix `i'_allci = `i'_allci\(r(se))*1.959960458
  }
  
 }
  lincom income*`sd2_income'
   matrix `i'_all = `i'_all\(r(estimate))
   matrix `i'_allci = `i'_allci\(r(se))*1.959960458
  lincom educC_5-educC_2
   matrix `i'_all = `i'_all\(r(estimate))
   matrix `i'_allci = `i'_allci\(r(se))*1.959960458
}
matrix full_all = b_ideol_withns_all, ecoSTD_all, socSTD_all, b_ideol_withns_allci, ecoSTD_allci, socSTD_allci
*rows are personality traits, BF_co, BF_op, BF_ag, BF_st, BF_ex
*cols are effect of 2sd change, first in xb for eco, soc, ideo, pid5 then ci for those xb estimates
matrix list full_all

**************************
*** Table 5, Tobit, Personality Effects by Context/Race
**************************

*** Interactions, all covariates with race
foreach i in female age age2 {
 gen Y1_b_`i'=r_black*`i'
 gen Y1_h_`i'=r_hispanic*`i'
 gen Y1_o_`i'=r_other*`i'
}

foreach i in educC_1 educC_2 educC_4 educC_5 educC_6 income incomemis {
 gen Y2_b_`i'=r_black*`i'
 gen Y2_h_`i'=r_hispanic*`i'
 gen Y2_o_`i'=r_other*`i'
}

* Loop over DV's
foreach i in b_ideol_withns ecoSTD socSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01

 *race interactions, two specifications (with and without income and eduation)
 tobit `i' BF_* BF*r_* female r_black r_hispanic r_other age age2 stateC_* [pweight=psweight], cluster(profile66)  ll(`mini') ul(`maxi')
 test BFexXr_black BFagXr_black BFcoXr_black BFstXr_black BFopXr_black BFexXr_hispanic BFagXr_hispanic BFcoXr_hispanic BFstXr_hispanic BFopXr_hispanic BFexXr_other BFagXr_other BFcoXr_other BFstXr_other BFopXr_other 
 *if first dv, then replace outreg, else append to outreg
 if "`i'"=="b_ideol_withns" {
  outreg BF_* BF*r_* female r_black r_hispanic r_other age age2 using "logs/table5groupeffects.out", se bracket rdec(3) adec(7) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc), "F test: Interactions", r(F), "Prob > F", r(p)) replace
 }
 else {
  outreg BF_* BF*r_* female r_black r_hispanic r_other age age2 using "logs/table5groupeffects.out", se bracket rdec(3) adec(7) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc), "F test: Interactions", r(F), "Prob > F", r(p)) append
 }
 tobit `i' BF_* BF*r_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66)  ll(`mini') ul(`maxi')
 test BFexXr_black BFagXr_black BFcoXr_black BFstXr_black BFopXr_black BFexXr_hispanic BFagXr_hispanic BFcoXr_hispanic BFstXr_hispanic BFopXr_hispanic BFexXr_other BFagXr_other BFcoXr_other BFstXr_other BFopXr_other 
 outreg BF_* BF*r_* female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/table5groupeffects.out", se bracket rdec(3) adec(7) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc), "F test: Interactions", r(F), "Prob > F", r(p)) append

 *now with additional interactions
 tobit `i' BF_* BF*r_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* Y1_* Y2_* BF*Xfemale BF*XeducC_* BF*Xincome* BF*Xage* [pweight=psweight], cluster(profile66)  ll(`mini') ul(`maxi')
 test BFexXr_black BFagXr_black BFcoXr_black BFstXr_black BFopXr_black BFexXr_hispanic BFagXr_hispanic BFcoXr_hispanic BFstXr_hispanic BFopXr_hispanic BFexXr_other BFagXr_other BFcoXr_other BFstXr_other BFopXr_other 
 outreg BF_* BF*r_* female r_black r_hispanic r_other age age2 educC_* income incomemis Y1_* Y2_* BF*Xfemale BF*XeducC_* BF*Xincome* BF*Xage* using "logs/table5groupeffects.out", se bracket rdec(3) adec(7) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc), "F test: Interactions", r(F), "Prob > F", r(p)) append

}

*Build marginal effect matrix and spit back out
*Specification is #2 above

*set 2sd change in BF and Income in local vars
foreach i in co op ag st ex {
 quietly summ BF_`i' [aweight=psweight]
 local sd2_BF_`i'=2*r(sd)
}
quietly summ income if incomemis!=1
 local sd2_income=2*r(sd)

*Loop over DV
quietly foreach i in b_ideol_withns socSTD ecoSTD {

 quietly summ `i'
 local mini=r(min)+.01
 local maxi=r(max)-.01

 *Create race interactions
 quietly tobit `i' BF_* BF*r_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66)  ll(`mini') ul(`maxi')

 foreach j in co op ag st ex {
  
  lincom BF_`j'*`sd2_BF_`j''

  if "`j'"=="co" {
   matrix `i'_white = (r(estimate))
   matrix `i'_whiteci = (r(se))*1.959960458
   
  }
  else {
   matrix `i'_white = `i'_white\(r(estimate))
   matrix `i'_whiteci = `i'_whiteci\(r(se))*1.959960458
  }
  
  lincom BF_`j'*`sd2_BF_`j'' + BF`j'Xr_black*`sd2_BF_`j''   

  if "`j'"=="co" {
   matrix `i'_b = (r(estimate))
   matrix `i'_bci = (r(se))*1.959960458
   
  }
  else {
   matrix `i'_b = `i'_b\(r(estimate))
   matrix `i'_bci = `i'_bci\(r(se))*1.959960458
  }
 
 }

matrix `i'_group = `i'_white, `i'_b, `i'_whiteci, `i'_bci 

}

*rows are personality traits, BF_co, BF_op, BF_ag, BF_st, BF_ex
*cols are effect of 2sd change, first in xb for white, black, then ci for those xb estimates
foreach i in  b_ideol_withns ecoSTD socSTD {
 matrix list `i'_group
}

*** TIPI ITEM CORRELATIONS
*Big Five - conscientiousness
pwcorr b_p_dependable b_p_disorganized_R [aweight=psweight]

*Big Five - openness to experiences
pwcorr b_p_open b_p_conventional_R [aweight=psweight]

*Big Five - agreeableness
pwcorr b_p_sympathetic b_p_critical_R [aweight=psweight]

*Big Five - emotional stability
pwcorr b_p_calm b_p_anxious_R [aweight=psweight]

*Big Five - extraversion
pwcorr b_p_extraverted b_p_reserved_R [aweight=psweight]


******************************************************
**** ADDITIONAL TESTS DISCUSSED ON PAGE 123 **********
******************************************************
**** COMPARISON WITH RWA and RACIAL RESENTMENT ******* 
******************************************************
*************TOBIT MODELS******************
 quietly summ b_ideol_withns 
 local mini=r(min)+.01
 local maxi=r(max)-.01

 tobit b_ideol_withns BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66) ll(`mini') ul(`maxi')
 outreg BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) replace

 tobit b_ideol_withns authoritarianismSTD female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66) ll(`mini') ul(`maxi')
 outreg authoritarianismSTD female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) append

 tobit b_ideol_withns racialresentSTD female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [pweight=psweight], cluster(profile66) ll(`mini') ul(`maxi')
 outreg racialresentSTD female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) addstat("Left Censored Obs.", e(N_lc), "Right Censored Obs.", e(N_rc)) append

*************OLS MODELS******************
 reg b_ideol_withns BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight]

 reg b_ideol_withns BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight]
 outreg BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) append

 reg b_ideol_withns authoritarianismSTD female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight]
 outreg authoritarianismSTD female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) append

 reg b_ideol_withns racialresentSTD female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight]
 outreg racialresentSTD female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) append

*************ERRORS IN VARIABLES MODELS******************
 eivreg b_ideol_withns BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis stateC_* [aweight=psweight], r(BF_conscientiousness .68 BF_openness .56 BF_agreeableness .59 BF_stability .66 BF_extraversion .65) 
 outreg BF_* female r_black r_hispanic r_other age age2 educC_* income incomemis using "logs/comparisonwothermeasures.out", se bracket rdec(3) append

 eivreg b_ideol_withns female r_black r_hispanic r_other age age2 educC_* income incomemis authoritarianismSTD stateC_* [aweight=psweight], r(authoritarianismSTD .6842) 
 outreg female r_black r_hispanic r_other age age2 educC_* income incomemis authoritarianismSTD using "logs/comparisonwothermeasures.out", se bracket rdec(3) append

 eivreg b_ideol_withns female r_black r_hispanic r_other age age2 educC_* income incomemis racialresentSTD stateC_* [aweight=psweight], r(racialresentSTD .8647) 
 outreg female r_black r_hispanic r_other age age2 educC_* income incomemis racialresentSTD using "logs/comparisonwothermeasures.out", se bracket rdec(3) append